.. _glossary:

Glossary
========

.. glossary::
   :sorted:

   Jinja2
      A `templating system written by Armin Ronacher
      <http://jinja.pocoo.org/>`_.

   Pyramid
      A `web framework <http://pylonshq.com/pyramid>`_.

   Configurator
      `pyramid.config.Configurator
      <http://docs.pylonsproject.org/projects/pyramid/1.0/api/config.html#pyramid.config.Configurator>`_

   pyramid_jinja2
      A set of bindings that make templates written for the
      :term:`Jinja2` templating system work under the :term:`Pyramid` web framework.

   Template Inheritance
      Allows you to build a base “skeleton” template that contains all the common
      elements of your site and defines blocks that child templates can override.
      http://jinja.pocoo.org/docs/templates/#template-inheritance
